;; Generated package description from wcheck-mode.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "wcheck-mode" "2026.5" "General interface for text checkers" 'nil :commit "a5312ed2638a90a6e5340ec3315d9fa8eadc1fa6" :authors '(("Teemu Likonen" . "tlikonen@iki.fi")) :maintainer '("Teemu Likonen" . "tlikonen@iki.fi") :keywords '("text" "spell" "check" "languages" "ispell") :url "https://github.com/tlikonen/wcheck-mode")
